@@ -29,7 +29,7 @@ import re
 import tokenize
 
 
-__version__ = '0.2.8'
+__version__ = '0.3'
 
 
 try:
@@ -47,6 +47,20 @@ def format_code(source,
     Wrap summary lines if summary_wrap_length is greater than 0.
 
     """
+    try:
+        return _format_code(source,
+                            summary_wrap_length=summary_wrap_length,
+                            pre_summary_newline=pre_summary_newline,
+                            post_description_blank=post_description_blank)
+    except (tokenize.TokenError, IndentationError):
+        return source
+
+
+def _format_code(source,
+                 summary_wrap_length,
+                 pre_summary_newline,
+                 post_description_blank):
+    """Return source code with docstrings formatted."""
     if not source:
         return source
 
@@ -277,11 +291,12 @@ def format_file(filename, args, standard_out):
         else:
             import difflib
             diff = difflib.unified_diff(
-                io.StringIO(source).readlines(),
-                io.StringIO(formatted_source).readlines(),
+                source.splitlines(),
+                formatted_source.splitlines(),
                 'before/' + filename,
-                'after/' + filename)
-            standard_out.write(unicode().join(diff))
+                'after/' + filename,
+                lineterm='')
+            standard_out.write(unicode('\n').join(list(diff) + ['']))
 
 
 def main(argv, standard_out, standard_error):
@@ -317,9 +332,8 @@ def main(argv, standard_out, standard_error):
                 filenames += [os.path.join(root, f) for f in children
                               if f.endswith('.py') and
                               not f.startswith('.')]
-                for d in directories:
-                    if d.startswith('.'):
-                        directories.remove(d)
+                directories[:] = [d for d in directories
+                                  if not d.startswith('.')]
         else:
             try:
                 format_file(name, args=args, standard_out=standard_out)
